@@ -5,36 +5,36 @@ use 5.016;
 use strict;
 use warnings;
 
-$Geoffrey::Action::Constraint::ForeignKey::VERSION = '0.000101';
+$Geoffrey::Action::Constraint::ForeignKey::VERSION = '0.000102';
 
 use parent 'Geoffrey::Role::Action';
 
 sub add {
-    my ( $self, $hr_params ) = @_;
+    my ($self, $hr_params) = @_;
     require Ref::Util;
-    if ( !Ref::Util::is_hashref($hr_params) ) {
+    if (!Ref::Util::is_hashref($hr_params)) {
         require Geoffrey::Exception::General;
-        Geoffrey::Exception::General::throw_wrong_ref( __PACKAGE__ . '::add', 'hash' );
+        Geoffrey::Exception::General::throw_wrong_ref(__PACKAGE__ . '::add', 'hash');
     }
-    if ( !$self->converter->foreign_key ) {
+    if (!$self->converter->foreign_key) {
         require Geoffrey::Exception::NotSupportedException;
-        Geoffrey::Exception::NotSupportedException::throw_foreignkey( 'add', $self->converter );
+        Geoffrey::Exception::NotSupportedException::throw_foreignkey('add', $self->converter);
     }
-    if ( !exists $hr_params->{table} ) {
+    if (!exists $hr_params->{table}) {
         require Geoffrey::Exception::RequiredValue;
         Geoffrey::Exception::RequiredValue::throw_table_name();
     }
     if (   !exists $hr_params->{column}
         || !exists $hr_params->{reftable}
-        || !exists $hr_params->{refcolumn} )
+        || !exists $hr_params->{refcolumn})
     {
         require Geoffrey::Exception::RequiredValue;
-        Geoffrey::Exception::RequiredValue::throw_reftable_missing( $hr_params->{table} )
-          if ( !exists $hr_params->{reftable} );
-        Geoffrey::Exception::RequiredValue::throw_refcolumn_missing( $hr_params->{table} )
-          if ( !exists $hr_params->{refcolumn} );
-        Geoffrey::Exception::RequiredValue::throw_table_column( $hr_params->{table} )
-          if ( !exists $hr_params->{column} );
+        Geoffrey::Exception::RequiredValue::throw_reftable_missing($hr_params->{table})
+            if (!exists $hr_params->{reftable});
+        Geoffrey::Exception::RequiredValue::throw_refcolumn_missing($hr_params->{table})
+            if (!exists $hr_params->{refcolumn});
+        Geoffrey::Exception::RequiredValue::throw_table_column($hr_params->{table})
+            if (!exists $hr_params->{column});
     }
     $hr_params->{reftable} =~ s/"//g;
     $hr_params->{table} =~ s/"//g;
@@ -42,51 +42,53 @@ sub add {
     my $s_sql = Geoffrey::Utils::replace_spare(
         $self->converter->foreign_key->add,
         [
-            $hr_params->{column},    $hr_params->{reftable},
-            $hr_params->{refcolumn}, qq~fkey_$hr_params->{table}~ . q~_~ . time
-        ]
-    );
+            $hr_params->{column},
+            (exists $hr_params->{schema} ? $hr_params->{schema} . q/./ : q//)
+                . $hr_params->{reftable},
+            $hr_params->{refcolumn},
+            qq~fkey_$hr_params->{table}~ . q~_~ . time
+        ]);
     return $s_sql if $self->for_table;
     return $self->do($s_sql);
 
 }
 
 sub alter {
-    my ( $self, $hr_params ) = @_;
-    if ( !exists $hr_params->{name} ) {
+    my ($self, $hr_params) = @_;
+    if (!exists $hr_params->{name}) {
         require Geoffrey::Exception::RequiredValue;
-        Geoffrey::Exception::RequiredValue::throw_index_name( __PACKAGE__ . '::alter' );
+        Geoffrey::Exception::RequiredValue::throw_index_name(__PACKAGE__ . '::alter');
     }
-    if ( !$self->converter->foreign_key ) {
+    if (!$self->converter->foreign_key) {
         require Geoffrey::Exception::NotSupportedException;
-        Geoffrey::Exception::NotSupportedException::throw_foreignkey( 'alter', $self->converter );
+        Geoffrey::Exception::NotSupportedException::throw_foreignkey('alter', $self->converter);
     }
-    return [ $self->drop($hr_params), $self->add($hr_params), ];
+    return [$self->drop($hr_params), $self->add($hr_params),];
 }
 
 sub drop {
-    my ( $self, $hr_params ) = @_;
-    if ( !$self->converter->foreign_key ) {
+    my ($self, $hr_params) = @_;
+    if (!$self->converter->foreign_key) {
         require Geoffrey::Exception::NotSupportedException;
-        Geoffrey::Exception::NotSupportedException::throw_foreignkey( 'drop',
-            $self->converter->foreign_key );
+        Geoffrey::Exception::NotSupportedException::throw_foreignkey('drop',
+            $self->converter->foreign_key);
     }
     require Geoffrey::Utils;
-    my $s_sql = Geoffrey::Utils::replace_spare( $self->converter->foreign_key->drop,
-        [ $hr_params->{table}, $hr_params->{name} ] );
+    my $s_sql = Geoffrey::Utils::replace_spare($self->converter->foreign_key->drop,
+        [$hr_params->{table}, $hr_params->{name}]);
     return $s_sql if $self->for_table;
     return $self->do($s_sql);
 }
 
 sub list_from_schema {
-    my ( $self, $schema ) = @_;
+    my ($self, $schema) = @_;
     my $converter = $self->converter;
-    if ( !$self->converter->foreign_key ) {
+    if (!$self->converter->foreign_key) {
         require Geoffrey::Exception::NotSupportedException;
-        Geoffrey::Exception::NotSupportedException::throw_foreignkey( 'list', $self->converter );
+        Geoffrey::Exception::NotSupportedException::throw_foreignkey('list', $self->converter);
     }
     return $converter->foreignkey_information(
-        $self->do_arrayref( $self->converter->foreign_key->list($schema) ) );
+        $self->do_arrayref($self->converter->foreign_key->list($schema)));
 }
 
 1;
@@ -103,7 +105,7 @@ Geoffrey::Action::Constraint::ForeignKey - Action handler for foreign keys
 
 =head1 VERSION
 
-Version 0.000101
+Version 0.000102
 
 =head1 DESCRIPTION
 
